package com.example.pda.network

import android.util.Log
import com.example.pda.model.InventoryItem
import com.example.pda.model.ContainerData
import com.example.pda.model.loginItem
import com.example.pda.model.successItem
import kotlinx.coroutines.CoroutineScope
import kotlinx.coroutines.Dispatchers
import kotlinx.coroutines.launch
import kotlin.collections.orEmpty

// 网络请求助手对象，用于处理与服务器的交互
object NetworkHelper {
    private const val TAG = "NetworkHelper"

    // 提交库存数据到服务器的方法
    fun submitData(
        data: ContainerData, // 库存数据列表
        onSuccess: () -> Unit, // 提交成功后的回调函数
        onError: (String) -> Unit // 提交失败后的回调函数
    ) {
        // 在IO线程中启动协程以执行网络请求
        CoroutineScope(Dispatchers.IO).launch {
            try {
                // 调用RetrofitClient的submitInventory方法提交数据
                val response = RetrofitClient.instance.submitInventory(data)
                // 检查HTTP响应是否成功
                if (response.isSuccessful) {
                    // 如果响应体存在且code为200，则调用成功回调
                    response.body()?.let {
                        if (it.code == 200) {
                            onSuccess()
                        } else {
                            // 否则调用错误回调并传递错误信息
                            onError(it.message ?: "Unknown error")
                        }
                    }
                } else {
                    // 如果HTTP响应不成功，则调用错误回调并传递HTTP错误代码
                    onError("HTTP Error: ${response.code()}")
                }
            } catch (e: Exception) {
                // 捕获异常并记录日志，之后调用错误回调并传递异常本地化信息
                Log.e(TAG, "Submit failed", e)
                onError("Network error: ${e.localizedMessage}")
            }
        }
    }

    // 获取库存列表的方法
    fun getIdList(
        container_code: String,

        onSuccess: (List<InventoryItem>) -> Unit, // 成功后的回调函数，接受一个InventoryItem列表作为参数
        onError: (String) -> Unit // 失败后的回调函数
    ) {
        val params = mapOf("code" to container_code)
        // 在IO线程中启动协程以执行网络请求
        CoroutineScope(Dispatchers.IO).launch {
            try {
                val response = RetrofitClient.instance.getInventoryList(params)
                // 检查HTTP响应是否成功
                if (response.isSuccessful) {
                    // 如果响应体存在且code为200，则调用成功回调，并将数据传递给回调函数

                    response.body()?.let {
                        if (it.code == 200) {
                            onSuccess(it.data.orEmpty())
                        } else {
                            // 否则调用错误回调并传递错误信息
                            onError(it.message ?: "Unknown error")
                        }
                    }
                } else {
                    // 如果HTTP响应不成功，则调用错误回调并传递HTTP错误代码
                    onError("HTTP Error: ${response.code()}")
                }
            } catch (e: Exception) {
                // 捕获异常并记录日志，之后调用错误回调并传递异常本地化信息
                Log.e(TAG, "Get failed", e)
                onError("Network error: ${e.localizedMessage}")
            }
        }
    }

    fun userlogin(
        data : loginItem,
        onSuccess: (successItem) -> Unit,
        onError: (String) -> Unit
    )
    {
        CoroutineScope(Dispatchers.IO).launch {
            try {
                val response = RetrofitClient.instance.login(data)
                if (response.isSuccessful) {
                    response.body()?.let {
                        if (it.code == 200) {
                            onSuccess(it.data)
                        } else {
                            onError(it.message ?: "Unknown error")
                        }
                    }
                } else {
                    onError("HTTP Error: ${response.code()} ${response.message()}")
                }
            } catch (e: Exception) {
                Log.e(TAG, "Login failed", e)
                onError("Network error: ${e.localizedMessage}")
            }
            }

    }
}
