package com.example.pda.network

import android.util.Log
import kotlinx.coroutines.CoroutineScope
import kotlinx.coroutines.Dispatchers
import kotlinx.coroutines.launch
import kotlinx.coroutines.withContext

//// 网络检测对象，用于执行网络可达性检查
//object NetworkPinger {
//    private const val TAG = "NetworkPinger"
//    private val repository = PingRepository()
//
//    /**
//     * 执行网络可达性检查
//     * @param url 需要检测的完整地址（必须包含协议头）
//     * @param onSuccess 检测成功的回调（响应码在200-299之间）
//     * @param onError 检测失败的回调，携带错误信息
//     */
//    fun ping(
//        url: String,
//        onSuccess: () -> Unit,
//        onError: (String) -> Unit
//    ) {
////        // 前置条件检查
////        if (!url.startsWith("http://") && !url.startsWith("https://")) {
////            onError("Invalid URL protocol")
////            return
////        }
//
//        CoroutineScope(Dispatchers.IO).launch {
//            try {
//                Log.d(TAG, "Starting ping to $url")
//                val result = repository.ping(url)
//
//                withContext(Dispatchers.Main) {
//                    if (result) {
//                        Log.d(TAG, "Ping to $url succeeded")
//                        onSuccess()
//                    } else {
//                        Log.w(TAG, "Ping to $url failed")
//                        onError("Request completed but not successful")
//                    }
//                }
//            } catch (e: Exception) {
//                withContext(Dispatchers.Main) {
//                    val errorMsg = when (e) {
//                        is IllegalArgumentException -> "Invalid URL format"
//                        else -> "Network error: ${e.localizedMessage}"
//                    }
//                    Log.e(TAG, "Ping to $url failed: ${e.javaClass.simpleName}")
//                    onError(errorMsg)
//                }
//            }
//        }
//    }
//
//    // 内部仓库类处理具体请求逻辑
//    private class PingRepository {
//        /**
//         * 执行实际的ping操作
//         * @return Boolean 是否收到成功响应
//         * @throws IllegalArgumentException 当URL格式无效时
//         */
//        suspend fun ping(url: String): Boolean {
//            validateUrl(url)
//            return try {
//                val response = RetrofitPing.pingService.ping(url)
//                response.isSuccessful
//            } catch (e: Exception) {
//                Log.e(TAG, "Ping request failed", e)
//                false
//            }
//        }
//
//        /**
//         * 验证URL格式有效性
//         * @throws IllegalArgumentException 如果URL格式无效
//         */
//        private fun validateUrl(url: String) {
//            if (!url.matches(Regex("^https?://.*"))) {
//                throw IllegalArgumentException("Invalid URL format")
//            }
//        }
//    }
//}
object NetworkPinger {
    private const val TAG = "NetworkPinger"
    private const val TIMEOUT = 1000 // 超时时间（毫秒）
    private const val PING_COUNT = 1 // 发送包数量

    fun ping(
        host: String, // 直接接收IP或主机名
        onSuccess: () -> Unit,
        onError: (String) -> Unit
    ) {
        CoroutineScope(Dispatchers.IO).launch {
            try {
                val process = ProcessBuilder().command(
                    "/system/bin/ping",
                    "-c", PING_COUNT.toString(),
                    "-W", (TIMEOUT / 1000).toString(),
                    host
                ).redirectErrorStream(true).start()

                val exitCode = withContext(Dispatchers.IO) {
                    process.waitFor() // 等待进程结束
                }

                val output = process.inputStream.bufferedReader().use { it.readText() }

                withContext(Dispatchers.Main) {
                    if (exitCode == 0 && output.contains("ttl=", true)) {
                        Log.d(TAG, "Ping to $host succeeded")
                        onSuccess()
                    } else {
                        val errorMsg = when {
                            output.contains("Network is unreachable") -> "网络不可达"
                            output.contains("unknown host") -> "无效的主机地址"
                            else -> "请求超时（${TIMEOUT}ms）"
                        }
                        Log.w(TAG, "Ping failed: $errorMsg")
                        onError(errorMsg)
                    }
                }
            } catch (e: Exception) {
                withContext(Dispatchers.Main) {
                    val errorMsg = when (e) {
                        is SecurityException -> "缺少网络权限"
                        else -> "系统错误: ${e.localizedMessage}"
                    }
                    Log.e(TAG, "Ping execution failed", e)
                    onError(errorMsg)
                }
            }
        }
    }
}