package com.example.pda.ui

import androidx.compose.foundation.layout.*
import androidx.compose.foundation.lazy.LazyColumn
import androidx.compose.foundation.lazy.itemsIndexed
import androidx.compose.foundation.text.KeyboardOptions
import androidx.compose.material3.SnackbarHost
import androidx.compose.material3.SnackbarHostState

import androidx.compose.material.icons.Icons
import androidx.compose.material.icons.filled.ArrowBack
import androidx.compose.material.icons.filled.Home

import androidx.compose.material3.Scaffold
import androidx.compose.material3.*
import androidx.compose.runtime.Composable
import androidx.compose.runtime.LaunchedEffect
import androidx.compose.runtime.collectAsState
import androidx.compose.runtime.mutableStateListOf
import androidx.compose.runtime.remember
import androidx.compose.runtime.rememberCoroutineScope
import androidx.compose.ui.Alignment
import androidx.compose.ui.Modifier
import androidx.compose.ui.res.painterResource
import androidx.compose.ui.text.input.KeyboardType
import androidx.compose.ui.text.style.TextOverflow
import androidx.compose.ui.unit.dp
import androidx.lifecycle.viewmodel.compose.viewModel

import com.example.pda.R
import com.example.pda.function.ResultCount
import com.example.pda.function.ResultCounter
import com.example.pda.model.AppPrefs
import com.example.pda.ui.viewmodel.InventoryViewModel
import com.example.pda.model.InventoryItem
import com.example.pda.model.ContainerData
import kotlinx.coroutines.launch


@OptIn(ExperimentalMaterial3Api::class)
@Composable

fun DetailsScreen(
    container: String,
    result: String,
    onBack: () -> Unit,
    onMainScreen: () -> Unit,
    onShelfScan: () -> Unit,

    ) {
    val snackbarHostState = remember { SnackbarHostState() }
    val scope = rememberCoroutineScope()
    val resultCounter = ResultCounter()
    val viewModel: InventoryViewModel = viewModel()
    val editableResults = remember {
        mutableStateListOf<ResultCount>().apply {
            addAll(resultCounter.getStatistics())
        }
    }
    // 使用 mutableStateList 保证Compose能感知变化
    val inventoryitems = remember { mutableStateListOf<InventoryItem>() }


    // 初始化数据
    LaunchedEffect(Unit) {
        result.split(",").forEach {
            resultCounter.addResult(it)
        }
        editableResults.clear()
        editableResults.addAll(resultCounter.getStatistics())

        // 初始化库存列表
        inventoryitems.clear()
        inventoryitems.addAll(
            editableResults.map {
                InventoryItem(it.normalizedResult, it.occurrences)
            }
        )
    }

    // 更新文本输入时的数据同步
    fun updateInventoryItem(index: Int, newCount: Int) {
        editableResults[index] = editableResults[index].copy(occurrences = newCount)
        inventoryitems[index] = inventoryitems[index].copy(occurrences = newCount)
    }

    // 提交按钮的统一处理
    fun onSubmit() {
        val items = editableResults.map {
            InventoryItem(it.normalizedResult, it.occurrences)
        }
        inventoryitems.clear()
        inventoryitems.addAll(items)
    }
    val uiState = viewModel.uiState.collectAsState()

    LaunchedEffect(uiState.value) {
        when (val currentState = uiState.value) {
            is InventoryViewModel.UiState.Success -> {
                scope.launch {
                    snackbarHostState.showSnackbar(currentState.message)
                    viewModel.resetState()
                }
                resultCounter.clear()
                editableResults.clear()
            }
            is InventoryViewModel.UiState.Error -> {
                scope.launch {
                    snackbarHostState.showSnackbar("错误：${currentState.message}")
                    viewModel.resetState()
                }
            }
            else -> {}
        }
    }

    Scaffold(
        snackbarHost = { SnackbarHost(snackbarHostState) },
        topBar = {
            TopAppBar(
                title = { Text("扫描结果详情") },
                navigationIcon = {
                    IconButton(onClick = onBack) {
                        Icon(
                            imageVector = Icons.Default.ArrowBack,
                            contentDescription = "返回"
                        )
                    }
                }
            )
        },
        floatingActionButton = {
            Box(
                 modifier = Modifier.fillMaxWidth(),
                 contentAlignment = Alignment.Center

            ) {
            Row(
            modifier = Modifier
                .fillMaxWidth().padding(20.dp) ,
            verticalAlignment = Alignment.CenterVertically,
            horizontalArrangement = Arrangement.SpaceEvenly,

            ) {
                ExtendedFloatingActionButton(
                    modifier = Modifier.weight(1f),
                    onClick = onMainScreen,
                    icon = {
                        Icon(
                            imageVector = Icons.Default.Home,
                            contentDescription = "返回主页"
                        )
                       },
                    text = { Text("主页") }
                )

                Spacer(Modifier.width(8.dp)) // 添加间距

                ExtendedFloatingActionButton(
                    modifier = Modifier.weight(1f),
                    onClick = onShelfScan,
                    icon = {
                        Icon(
                            painter = painterResource(id = R.drawable.ic_scan),
                            contentDescription = "货架扫描"
                        )
                    },
                    text = { Text("托盘") }
                )
                Spacer(Modifier.width(8.dp)) // 添加间距

                ExtendedFloatingActionButton(
                    modifier = Modifier.weight(1f),

                    onClick ={
                        onSubmit()
                        val containerData = ContainerData(
                            container = container,
                            batches = inventoryitems.toList(),
                            username = AppPrefs.username
                        )
                        viewModel.submitData(containerData)
                             } ,
                    icon = {
                        Icon(
                            painter = painterResource(id = R.drawable.ic_scan),
                            contentDescription = "组盘入库"
                        )
                    },
                    text = { Text("组盘入库") }
                )
            }
            }
        }
    ) { innerPadding ->
        Column(
            modifier = Modifier
                .padding(innerPadding)
                .fillMaxSize()
                .padding(24.dp)
        ) {
            Text(
                text = "扫描结果：",
                style = MaterialTheme.typography.titleLarge
            )

            Spacer(modifier = Modifier.height(16.dp))

            Card(
                modifier = Modifier.fillMaxWidth()
            ) {
                Text(
                    text = container,
                    modifier = Modifier.padding(16.dp),
                    style = MaterialTheme.typography.bodyLarge,
                    overflow = TextOverflow.Ellipsis,
                    maxLines = 5
                )
            }
            // 观察状态变化

            // 新增统计列表
            Spacer(modifier = Modifier.height(24.dp))
            Row(
                modifier = Modifier.fillMaxWidth(),
                horizontalArrangement = Arrangement.SpaceBetween
            ) {
                Text("条码", style = MaterialTheme.typography.titleMedium)
                Text("数量", style = MaterialTheme.typography.titleMedium)
            }

            LazyColumn(
                modifier = Modifier
                    .fillMaxWidth()
                    .weight(1f)
            ) {
                itemsIndexed(editableResults) { index, item ->
                    Row(
                        modifier = Modifier
                            .fillMaxWidth()
                            .padding(vertical = 8.dp),
                        verticalAlignment = Alignment.CenterVertically,
                        horizontalArrangement = Arrangement.SpaceBetween
                    ) {
                        Text(
                            text = item.normalizedResult,
                            modifier = Modifier.weight(1f),
                            overflow = TextOverflow.Ellipsis,
                            maxLines = 1
                        )

                        Spacer(modifier = Modifier.width(16.dp))

                        OutlinedTextField(
                            value = item.occurrences.toString(),
                            onValueChange = { newValue ->
                                newValue.toIntOrNull()?.let { updateInventoryItem(index, it) }

                            },
                            modifier = Modifier.width(100.dp),
                            keyboardOptions = KeyboardOptions.Default.copy(
                                keyboardType = KeyboardType.Number
                            )
                        )
                    }
                }
            }


        }
    }
}



